pub struct Http3Settings {
pub max_requests_per_connection: Option<u64>,
pub max_header_list_size: Option<u64>,
pub qpack_max_table_capacity: Option<u64>,
pub qpack_blocked_streams: Option<u64>,
pub post_accept_timeout: Option<Duration>,
pub enable_extended_connect: bool,
pub max_recv_body_buf_size: Option<usize>,
}Expand description
Unified configuration parameters for H3Drivers.
Fields
max_requests_per_connection: Option<u64>Maximum number of requests a ServerH3Driver allows per connection.
max_header_list_size: Option<u64>Maximum size of a single HEADERS frame, in bytes.
qpack_max_table_capacity: Option<u64>Maximum value the QPACK encoder is permitted to set for the dynamic table capcity. See https://www.rfc-editor.org/rfc/rfc9204.html#name-maximum-dynamic-table-capac
qpack_blocked_streams: Option<u64>Upper bound on the number of streams that can be blocked on the QPACK decoder. See https://www.rfc-editor.org/rfc/rfc9204.html#name-blocked-streams
post_accept_timeout: Option<Duration>Timeout between starting the QUIC handshake and receiving the first request on a connection. Only applicable to ServerH3Driver.
enable_extended_connect: boolSet the SETTINGS_ENABLE_CONNECT_PROTOCOL HTTP/3 setting.
See https://www.rfc-editor.org/rfc/rfc9220#section-3-2
max_recv_body_buf_size: Option<usize>Maximum size, in bytes, of the buffer the driver uses to read HTTP/3 body data out of quiche before forwarding it upstream.
The buffer is sized dynamically to the amount of data currently readable on a stream (which is itself bounded by the QUIC flow-control window and the size of the buffered QUIC STREAM frames), but a single read will never allocate more than this cap. This bounds the memory a single (potentially adversarial) stream can force the driver to allocate.
When unset or Some(0), the driver defaults to 16 KiB.